@@ -18,11 +18,12 @@ def execute(
     maxW: int = typer.Option(8, '-w','--maxW', help="Maximum width of stripe."),
     maxpixel: str = typer.Option('0.95,0.96,0.97,0.98,0.99','-m','--maxpixel', help="Percentiles of the contact frequency data to saturate the image. Separated by comma"),
     numcores: int = typer.Option(multiprocessing.cpu_count(), '-n','--numcores', help='The number of cores will be used.'),
-    pvalue: float = typer.Option(0.1, '-p', '--pvalue', help='P-value cutoff for stripe.')
+    pvalue: float = typer.Option(0.1, '-p', '--pvalue', help='P-value cutoff for stripe.'),
+    mask: str = typer.Option('0', "--mask", help='Column coordinates to be masked. e.g., chr9:12345678-12345789')
 ):
     """Finds stripe coordinates from 3D genomic data
     """
-    stripenn.compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue)
+    stripenn.compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask)
 
 @app.command('seeimage')
 def seeimag(
@@ -42,14 +43,13 @@ def scoring(
     cool: str = typer.Option(..., "--cool",help="Path to cool file"),
     coordinates: str = typer.Option(..., "--coord",'-c', help="Path to stripe coordinate table"),
     norm: str = typer.Option('KR',"--norm",help="Normalization method. It should be one of the column name of Cooler.bin(). Check it with Cooler.bins().columns (e.g., KR, VC, VC_SQRT)"),
-    header: bool = typer.Option(False, "--header", '-h', help="Does the stripe coordinate table have header?"),
     numcores: int = typer.Option(multiprocessing.cpu_count(), '-n','--numcores', help='The number of cores will be used.'),
     out: str = typer.Option('scores.out','--out','-o',help='Path to output file'),
     mask: str = typer.Option('0', "--mask", help='Column coordinates to be masked. e.g., chr9:12345678-12345789')
 ):
     """ Calculates p-value and stripiness of given stripes based on given 3D genome conformation data.
     """
-    score.getScore(cool, coordinates,norm,header,numcores,out,mask)
+    score.getScore(cool, coordinates,norm,numcores,out,mask)
 
 
 def main():
