@@ -214,78 +214,118 @@ class getStripe:
         samplesize[0] += dif
 
         def main_null_calc(chr):
-            background_size = 50000/self.resol
-            background_up = np.floor(background_size / 2)
-            background_down = background_size - background_up
-            background_up = int(background_up)
-            background_down = int(background_down)
-            background_size = int(background_size)
-            chr = str(chr)
-            np.seterr(divide='ignore', invalid='ignore')
-            #c = np.where(chromnames2 == chr)[0]
-            c = chromnames2.index(chr)
+            with np.errstate(divide='ignore', invalid='ignore'):
+                background_size = 50000/self.resol
+                background_up = np.floor(background_size / 2)
+                background_down = background_size - background_up
+                background_up = int(background_up)
+                background_down = int(background_down)
+                background_size = int(background_size)
+                chr = str(chr)
+                np.seterr(divide='ignore', invalid='ignore')
+                #c = np.where(chromnames2 == chr)[0]
+                c = chromnames2.index(chr)
 
-            # Modified in Dec 11 2020
-            ss = samplesize[c]
-            chrsize = self.chromnames2sizes[chr]
-            itera = min(chrsize/self.resol/500, 25)
-            itera = np.uint64(itera)
-            unitsize = np.floor(chrsize/self.resol/itera)
-            unitsize = np.uint64(unitsize)
+                # Modified in Dec 11 2020
+                ss = samplesize[c]
+                chrsize = self.chromnames2sizes[chr]
+                itera = min(chrsize/self.resol/500, 25)
+                itera = np.uint64(itera)
+                unitsize = np.floor(chrsize/self.resol/itera)
+                unitsize = np.uint64(unitsize)
 
-            bgleft = np.zeros((400, 0))
-            bgright = np.zeros((400, 0))
+                bgleft = np.zeros((400, 0))
+                bgright = np.zeros((400, 0))
 
-            n_pool = []
+                n_pool = []
 
-            for it in range(itera):
-                sss = np.uint64(ss/itera)
-                test_region_start1 = np.uint64(unitsize * self.resol * it+1)
-                test_region_end1 = np.uint64(unitsize * self.resol * (it+1))
-                test_region_start2 = np.uint64(unitsize * self.resol * it+1)
-                test_region_end2 = np.uint64(unitsize * self.resol * (it+1)+(400*self.resol))
-                if test_region_end2 > chrsize:
-                    test_region_end2 = chrsize-1
-                if test_region_end1 > chrsize - 400*self.resol:
-                    test_region_end1 = chrsize - 400*self.resol
+                for it in range(itera):
+                    sss = np.uint64(ss/itera)
+                    test_region_start1 = np.uint64(unitsize * self.resol * it+1)
+                    test_region_end1 = np.uint64(unitsize * self.resol * (it+1))
+                    test_region_start2 = np.uint64(unitsize * self.resol * it+1)
+                    test_region_end2 = np.uint64(unitsize * self.resol * (it+1)+(400*self.resol))
+                    if test_region_end2 > chrsize:
+                        test_region_end2 = chrsize-1
+                    if test_region_end1 > chrsize - 400*self.resol:
+                        test_region_end1 = chrsize - 400*self.resol
 
-                position1 = str(chr) + ":" + str(test_region_start1) + "-" + str(test_region_end1)
-                position2 = str(chr) + ":" + str(test_region_start2) + "-" + str(test_region_end2)
-                mat = self.unbalLib.fetch(position2, position1)
-                mat = nantozero(mat)
-                mat = np.round(mat, 1)
-                nrow = mat.shape[0]
-                matsum = np.sum(mat, axis=1)
-                zeroindex = np.where(matsum == 0)
-                pool = [x for x in list(range(nrow)) if x not in zeroindex[0].tolist()]
-                n_pool.append(len(pool))
-                if len(pool) == 0:
-                    del mat
-                elif len(pool) < sss:
-                    randval = random.choices(pool, k=len(pool))
-                    tableft = np.zeros((400, len(pool)))
-                    tabcenter = np.zeros((400, len(pool)))
-                    tabright = np.zeros((400, len(pool)))
+                    position1 = str(chr) + ":" + str(test_region_start1) + "-" + str(test_region_end1)
+                    position2 = str(chr) + ":" + str(test_region_start2) + "-" + str(test_region_end2)
+                    mat = self.unbalLib.fetch(position2, position1)
+                    mat = nantozero(mat)
+                    mat = np.round(mat, 1)
+                    nrow = mat.shape[0]
+                    matsum = np.sum(mat, axis=1)
+                    zeroindex = np.where(matsum == 0)
+                    pool = [x for x in list(range(nrow)) if x not in zeroindex[0].tolist()]
+                    n_pool.append(len(pool))
+                    if len(pool) == 0:
+                        del mat
+                    elif len(pool) < sss:
+                        randval = random.choices(pool, k=len(pool))
+                        tableft = np.zeros((400, len(pool)))
+                        tabcenter = np.zeros((400, len(pool)))
+                        tabright = np.zeros((400, len(pool)))
 
-                    for i in range(len(pool)):
-                        x = randval[i]
-                        for j in range(0,400):
-                            y = x + j
-                            tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up-background_size):(x - background_up)])
-                            tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
-                            tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
-                    bgleft_temp = np.subtract(tabcenter, tableft)
-                    bgright_temp = np.subtract(tabcenter, tabright)
-                    bgleft = np.column_stack((bgleft, bgleft_temp))
-                    bgright = np.column_stack((bgright, bgright_temp))
-                    del mat
-                else:
-                    randval = random.choices(pool, k=sss)
-                    tableft = np.zeros((400, sss))
-                    tabcenter = np.zeros((400, sss))
-                    tabright = np.zeros((400, sss))
+                        for i in range(len(pool)):
+                            x = randval[i]
+                            for j in range(0,400):
+                                y = x + j
+                                tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up-background_size):(x - background_up)])
+                                tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
+                                tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
+                        bgleft_temp = np.subtract(tabcenter, tableft)
+                        bgright_temp = np.subtract(tabcenter, tabright)
+                        bgleft = np.column_stack((bgleft, bgleft_temp))
+                        bgright = np.column_stack((bgright, bgright_temp))
+                        del mat
+                    else:
+                        randval = random.choices(pool, k=sss)
+                        tableft = np.zeros((400, sss))
+                        tabcenter = np.zeros((400, sss))
+                        tabright = np.zeros((400, sss))
 
-                    for i in range(sss):
+                        for i in range(sss):
+                            x = randval[i]
+                            for j in range(0, 400):
+                                y = x + j
+                                tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up - background_size):(x - background_up)])
+                                tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
+                                tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
+                        bgleft_temp = np.subtract(tabcenter, tableft)
+                        bgright_temp = np.subtract(tabcenter, tabright)
+                        del mat
+                        bgleft = np.column_stack((bgleft, bgleft_temp))
+                        bgright = np.column_stack((bgright, bgright_temp))
+
+                depl = np.uint64(ss - bgleft.shape[1])
+                if depl > 0:
+                    rich = np.argmax(n_pool)
+                    test_region_start1 = np.uint64(unitsize * self.resol * rich+1)
+                    test_region_end1 = np.uint64(unitsize * self.resol * (rich+1))
+                    test_region_start2 = np.uint64(unitsize * self.resol * rich+1)
+                    test_region_end2 = np.uint64(unitsize * self.resol * (rich+1)+(400*self.resol))
+                    if test_region_end2 > chrsize:
+                        test_region_end2 = chrsize-1
+                    if test_region_end1 > chrsize - 400*self.resol:
+                        test_region_end1 = chrsize - 400*self.resol
+
+                    position1 = str(chr) + ":" + str(test_region_start1) + "-" + str(test_region_end1)
+                    position2 = str(chr) + ":" + str(test_region_start2) + "-" + str(test_region_end2)
+                    mat = self.unbalLib.fetch(position2, position1)
+                    mat = nantozero(mat)
+                    mat = np.round(mat, 1)
+                    nrow = mat.shape[0]
+                    matsum = np.sum(mat, axis=1)
+                    zeroindex = np.where(matsum == 0)
+                    pool = [x for x in list(range(nrow)) if x not in zeroindex[0].tolist()]
+                    randval = random.choices(pool, k=depl)
+                    tableft = np.zeros((400, depl))
+                    tabcenter = np.zeros((400, depl))
+                    tabright = np.zeros((400, depl))
+
+                    for i in range(depl):
                         x = randval[i]
                         for j in range(0, 400):
                             y = x + j
@@ -298,46 +338,7 @@ class getStripe:
                     bgleft = np.column_stack((bgleft, bgleft_temp))
                     bgright = np.column_stack((bgright, bgright_temp))
 
-            depl = np.uint64(ss - bgleft.shape[1])
-            if depl > 0:
-                rich = np.argmax(n_pool)
-                test_region_start1 = np.uint64(unitsize * self.resol * rich+1)
-                test_region_end1 = np.uint64(unitsize * self.resol * (rich+1))
-                test_region_start2 = np.uint64(unitsize * self.resol * rich+1)
-                test_region_end2 = np.uint64(unitsize * self.resol * (rich+1)+(400*self.resol))
-                if test_region_end2 > chrsize:
-                    test_region_end2 = chrsize-1
-                if test_region_end1 > chrsize - 400*self.resol:
-                    test_region_end1 = chrsize - 400*self.resol
-
-                position1 = str(chr) + ":" + str(test_region_start1) + "-" + str(test_region_end1)
-                position2 = str(chr) + ":" + str(test_region_start2) + "-" + str(test_region_end2)
-                mat = self.unbalLib.fetch(position2, position1)
-                mat = nantozero(mat)
-                mat = np.round(mat, 1)
-                nrow = mat.shape[0]
-                matsum = np.sum(mat, axis=1)
-                zeroindex = np.where(matsum == 0)
-                pool = [x for x in list(range(nrow)) if x not in zeroindex[0].tolist()]
-                randval = random.choices(pool, k=depl)
-                tableft = np.zeros((400, depl))
-                tabcenter = np.zeros((400, depl))
-                tabright = np.zeros((400, depl))
-
-                for i in range(depl):
-                    x = randval[i]
-                    for j in range(0, 400):
-                        y = x + j
-                        tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up - background_size):(x - background_up)])
-                        tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
-                        tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
-                bgleft_temp = np.subtract(tabcenter, tableft)
-                bgright_temp = np.subtract(tabcenter, tabright)
-                del mat
-                bgleft = np.column_stack((bgleft, bgleft_temp))
-                bgright = np.column_stack((bgright, bgright_temp))
-
-                return bgleft, bgright
+                    return bgleft, bgright
         # apply parallel.
         print('2. Constituting background ... \n')
         result = Parallel(n_jobs=self.core)(delayed(main_null_calc)(chr) for chr in tqdm(chromnames2))
@@ -581,7 +582,10 @@ class getStripe:
 
             for x in range(len(x_seq)):
                 for y in range(len(y_seq)):
-                    expec_matrix[y,x] = exval[index_matrix[y][0][x]]
+                    idx = index_matrix[y][0][x]
+                    if idx >= 400:
+                        idx = 399
+                    expec_matrix[y,x] = exval[idx]
 
             del index_matrix
             return expec_matrix
