@@ -113,7 +113,7 @@ def makeOutDir(outdir):
     ld = np.subtract(amean,lefmean)
     rd = np.subtract(amean,rigmean)
     '''
-def addlog(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue):
+def addlog(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask):
     if out[-1] != '/':
         out += '/'
     outfile=open(out + "stripenn.log",'w')
@@ -127,17 +127,17 @@ def addlog(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue
     outfile.write('maxpixel: ' + str(maxpixel) + '\n')
     outfile.write('num_cores: ' + str(numcores) + '\n')
     outfile.write('pvalue: ' + str(pvalue) + '\n')
-
+    outfile.write('mask: ' + str(mask) + '\n')
     outfile.close()
     
     
-def compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue):
+def compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask):
     np.seterr(divide='ignore', invalid='ignore')
     t_start = time.time()
     if out[-1] != '/':
         out += '/'
     makeOutDir(out)
-    addlog(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue)
+    addlog(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask)
     maxpixel = maxpixel.split(',')
     maxpixel = list(map(float, maxpixel))
     chroms = chrom.split(',')
@@ -163,11 +163,12 @@ def compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalu
 
     all_chromnames = Lib.chromnames
     all_chromsizes = Lib.chromsizes
-    chrom_remain_idx = np.where(all_chromsizes > 500000)[0]
+    chrom_remain_idx = [i for i in range(len(all_chromnames)) if 'JH5' not in all_chromnames[i] and 'GL4' not in all_chromnames[i] and all_chromnames[i] != 'M' and all_chromnames[i] != "chrM" and all_chromnames[i] != "Y" and all_chromnames[i] != "chrY"]
     all_chromnames = [all_chromnames[i] for i in chrom_remain_idx]
     all_chromsizes = all_chromsizes[chrom_remain_idx]
     chromnames = all_chromnames
     chromsizes = all_chromsizes
+
     if len(all_chromnames) == 0:
         sys.exit("Exit: All chromosomes are shorter than 50kb.")
     warnflag = False
@@ -208,8 +209,8 @@ def compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalu
     result_table = getStripe.getStripe.RemoveRedundant(obj,df=result_table,by='pvalue')
 
     print('##########################\nStripiness calculation ...\n##########################\n')
-    s = obj.scoringstripes(result_table, EV)
-    s = s[1]
+    s = obj.scoringstripes(result_table, EV, mask)
+    s = s[0]
     result_table = result_table.drop(columns=['total', 'num', 'start', 'end', 'x', 'y', 'h', 'w', 'medpixel'])
     result_table.insert(result_table.shape[1],'Stripiness',s,True)
     res_filter = result_table[result_table['pvalue'] < pcut]
@@ -228,3 +229,4 @@ def compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalu
 
 #if __name__ == "__main__":
 #    main()
+
